[Rivet-svn] rivet: 3 new changesets

Rivet Mercurial rivet at projects.hepforge.org
Tue Sep 13 21:45:02 BST 2016


details:   https://rivet.hepforge.org/hg/rivet/rev/ba395b7568c4
branches:  release-2-5-x
changeset: 5471:ba395b7568c4
user:      Andy Buckley <andy at insectnation.org>
date:      Tue Sep 13 00:10:09 2016 +0100
description:
Add forward aliases for TauFinder and UnstableFinalState -- simplifying and rationalising the proj names

details:   https://rivet.hepforge.org/hg/rivet/rev/f93049b26509
branches:  release-2-5-x
changeset: 5472:f93049b26509
user:      Andy Buckley <andy at insectnation.org>
date:      Tue Sep 13 16:04:11 2016 +0100
description:
Extend Cuts == and != to doubles: there are real cases where this is useful, e.g. charge == 0

details:   https://rivet.hepforge.org/hg/rivet/rev/38857148b6cd
branches:  release-2-5-x
changeset: 5473:38857148b6cd
user:      Andy Buckley <andy at insectnation.org>
date:      Tue Sep 13 16:17:12 2016 +0100
description:
Add 'direct' versions of any, all, none to Utils.hh, with an implicity bool() transforming function.

diffs (truncated from 558 to 50 lines):

--- a/ChangeLog	Tue Sep 13 18:13:25 2016 +0100
+++ b/ChangeLog	Tue Sep 13 16:17:12 2016 +0100
@@ -1,7 +1,12 @@
+2016-09-13  Andy Buckley  <andy.buckley at cern.ch>
+
+	* Add 'direct' versions of any, all, none to Utils.hh, with an
+	implicity bool() transforming function.
+
 2016-09-13  Holger Schulz  <holger.schulz at cern.ch>
 
 	* Add and mark validated B+ to omega analysis (BABAR_2013_I1116411)
-	
+
 	* Add and mark validated D0 to pi- analysis (BABAR_2015_I1334693)
 
 	* Add a few more particle names and use PID names in recently added
--- a/include/Rivet/Projections/TauFinder.hh	Tue Sep 13 18:13:25 2016 +0100
+++ b/include/Rivet/Projections/TauFinder.hh	Tue Sep 13 16:17:12 2016 +0100
@@ -57,6 +57,10 @@
   };
 
 
+  /// @todo Make this the canonical name in future
+  using Taus = TauFinder;
+
+
 }
 
 
--- a/include/Rivet/Projections/UnstableFinalState.hh	Tue Sep 13 18:13:25 2016 +0100
+++ b/include/Rivet/Projections/UnstableFinalState.hh	Tue Sep 13 16:17:12 2016 +0100
@@ -20,7 +20,7 @@
   /// in the event record, i.e. those which differ only in bookkeeping details
   /// or photon emissions, are stripped from the returned particles collection.
   ///
   /// @todo Inherit directly from ParticleFinder, rename as UnstableFinder, and make TauFinder inherit/use
   class UnstableFinalState : public FinalState {
   public:
 
@@ -59,6 +59,10 @@
   };
 
 
+  /// @todo Make this the canonical name in future
+  using Unstables = UnstableFinalState;
+
+
 }
 
@@ -20,7 +20,7 @@
   /// or photon emissions, are stripped from the returned particles collection.
   ///
-  /// @todo Inherit directly from ParticleFinder, rename as UnstableFinder, and make TauFinder inherit/use
+  /// @todo Inherit directly from ParticleFinder, rename as Unstables, and make TauFinder inherit/use
   class UnstableFinalState : public FinalState {
   public:


More information about the Rivet-svn mailing list